# Generated by roxygen2: do not edit by hand

export(sparsify_moments)
export(subsample_moments)
export(two_sample_test)
importFrom(doParallel,registerDoParallel)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(foreach,registerDoSEQ)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(stats,complete.cases)
importFrom(stats,cov)
importFrom(stats,rbinom)
importFrom(stats,setNames)
